
#ifndef __ES_COMM_SYS_H__
#define __ES_COMM_SYS_H__

#include "es_common.h"
#include "es_type.h"
#include "es_errno.h"

#ifdef __cplusplus
#if __cplusplus
extern "C" {
#endif
#endif /* End of #ifdef __cplusplus */

#define BIND_DEST_MAXNUM 256

#define ES_TRACE_SYS(level, fmt, ...)                                                                         \
    do {                                                                                                      \
        ES_TRACE(level, ES_ID_SYS, "[Func]:%s [Line]:%d [Info]:" fmt, __FUNCTION__, __LINE__, ##__VA_ARGS__); \
    } while (0)

#define VERSION_NAME_MAXLEN 64
#define ES_SDK_VERSION "V1.0.0.0"
typedef struct esSYS_VERSION_S
{
    ES_CHAR version[VERSION_NAME_MAXLEN];
} SYS_VERSION_S;

typedef struct esBIND_DEST_S {
    ES_U32 num;
    CHN_S chn[BIND_DEST_MAXNUM];
} BIND_DEST_S;

typedef enum esVI_VPS_MODE_E {
    VI_OFFLINE_VPS_OFFLINE = 0,
    VI_OFFLINE_VPS_ONLINE,
    VI_ONLINE_VPS_OFFLINE,
    VI_ONLINE_VPS_ONLINE,
    VI_PARALLEL_VPS_OFFLINE,
    VI_PARALLEL_VPS_PARALLEL,
    VI_VPS_MODE_BUTT
} VI_VPS_MODE_E;

typedef enum {
    SYS_LOGLEVEL_TRACE = 0,
    SYS_LOGLEVEL_DEBUG = 1,
    SYS_LOGLEVEL_INFO = 2,
    SYS_LOGLEVEL_WARN = 3,
    SYS_LOGLEVEL_ERROR = 4,
    SYS_LOGLEVEL_FATAL = 5,
    SYS_LOGLEVEL_OFF = 6,
} SYS_LOGLEVEL_E;

#define ES_ERR_SYS_NULL_PTR ES_DEF_ERR(ES_ID_SYS, EN_ERR_LEVEL_ERROR, EN_ERR_NULL_PTR)
#define ES_ERR_SYS_NOTREADY ES_DEF_ERR(ES_ID_SYS, EN_ERR_LEVEL_ERROR, EN_ERR_SYS_NOTREADY)
#define ES_ERR_SYS_NOT_PERM ES_DEF_ERR(ES_ID_SYS, EN_ERR_LEVEL_ERROR, EN_ERR_NOT_PERM)
#define ES_ERR_SYS_NOMEM ES_DEF_ERR(ES_ID_SYS, EN_ERR_LEVEL_ERROR, EN_ERR_NOMEM)
#define ES_ERR_SYS_ILLEGAL_PARAM ES_DEF_ERR(ES_ID_SYS, EN_ERR_LEVEL_ERROR, EN_ERR_ILLEGAL_PARAM)
#define ES_ERR_SYS_BUSY ES_DEF_ERR(ES_ID_SYS, EN_ERR_LEVEL_ERROR, EN_ERR_BUSY)
#define ES_ERR_SYS_NOT_SUPPORT ES_DEF_ERR(ES_ID_SYS, EN_ERR_LEVEL_ERROR, EN_ERR_NOT_SUPPORT)

#ifdef __cplusplus
#if __cplusplus
}
#endif
#endif /* __cplusplus */

#endif /* __ES_COMM_SYS_H__ */
